! Module: gui_test_task_mod
!
! Author: Jon Brumfitt
!
! Description: Task to test GUI and parameter handling
! 
! Comments: 
! 
! $Id: gui_test_task_mod.f90,v 1.6 1999/06/18 14:12:51 jbrumfit Exp $
! 
module gui_test_task_mod

  use dal
  use param  
  
  implicit none 
  
  private 

  public gui_test_task

contains 
  
  subroutine gui_test_task

    character(len=128) :: stringpar
    character(len=128) :: filenamepar
    integer :: intpar
    logical :: printpars, boolpar, testwarn, testerror, testfatal, testmess
    real :: realpar
    integer :: i,n
    
    printpars = booleanParameter("print_params")
    if(printpars) then

      ! Test simple parameter types

      boolpar     = booleanParameter("boolean")
      intpar      = intParameter("integer")
      realpar     = realParameter("real")
      stringpar   = stringParameter("string")
      filenamepar = stringParameter("filename")

      write(*,*) 'boolean        = ', boolpar
      write(*,*) 'integer        = ', intpar
      write(*,*) 'real           = ', realpar
      write(*,*) 'string         = ', trim(stringpar)
      write(*,*) 'filename       = ', trim(filenamepar)

      ! Test parameter lists

      n = parameterCount("booleans")
      write(*,*)       'size(booleans) = ', n
      do i = 0, n-1
          write(*,*) 'booleans(',i,')  = ', booleanParameter("booleans",i)
      end do

      n = parameterCount("integers")
      write(*,*)       'size(integers) = ', n
      do i = 0, n-1
          write(*,*) 'integers(',i,')  = ', intParameter("integers",i)
      end do

      n = parameterCount("reals")
      write(*,*)       'size(reals)    = ', n
      do i = 0, n-1
          write(*,*) 'reals(',i,')     = ', realParameter("reals",i)
      end do

      n = parameterCount("strings")
      write(*,*)       'size(strings)  = ', n
      do i = 0, n-1
          write(*,*) 'strings(',i,')   = ', trim(stringParameter("strings",i))
      end do

      n = parameterCount("filenames")
      write(*,*)       'size(files)    = ', n
      do i = 0, n-1
          write(*,*) 'filenames(',i,') = ', trim(stringParameter("filenames",i))
      end do
    end if

    ! Optionally, force warnings, errors, etc

    testwarn    = booleanParameter("warning")
    testerror   = booleanParameter("error")
    testfatal   = booleanParameter("fatal")
    testmess    = booleanParameter("message")

    if(testwarn) then
        call warning("testWarn1", "This is a warning!")
        call warning("testWarn1", "The same warning again!")
        call warning("testWarn2", "This is a different warning")
    end if
    if(testerror) then
        call error("testError", "This is an error")
    end if
    if(testfatal) then
        call fatal("testFatal", "This is a fatal error")
    end if
    if(testmess) then
        call message(AppMsg, Verbose, "This is a message - verbosity = Verbose")
        call message(AppMsg, Sparse, "This is a message - verbosity = Sparse")
    end if

    write(*,*) 'Task exiting normally'

  end subroutine gui_test_task
  
end module gui_test_task_mod
