// -*-C++-*-
//
// File:      DalListView.h
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue Jul 25 14:56:30 MET DST 2000

#ifndef DalListView_h
#define DalListView_h

#include "DalListViewable.h"

#include <qlistview.h>
#include <qstring.h>

class DalListViewItem;
class Folder;

class DalListView : public QListView, public DalListViewable
{
  Q_OBJECT
public:
  DalListView(bool tree,QWidget* parent=0, const char* name=0);
  virtual ~DalListView();

  QString          selectedQualifiedName();
  DalListViewItem* openQualifiedName(const QString& n);

  // forwarded
  DalListViewItem* currentItem();
  DalListViewItem* selectedItem();
  DalListViewItem* firstChild();


  // Allow DalListViewables to be selected (defaut is any)
  void setSelectable(Type t) {_type=t;}
  Type type() {return _type;}

signals:
  void addSelection(DalListViewItem*);

  void leftClicked(DalListViewItem*);
  void rightClicked(DalListViewItem*,const QPoint&);
  void doubleClicked(DalListViewItem*); // == returnPressed(..)

public slots:
  // tree only
  void gotoParent();
  void jumpTo(DalListViewItem *);

  void handleLeftClicked(DalListViewItem*);
  void handleDoubleClicked(DalListViewItem*);

private slots:
  // forwarding only
  void handleSelectionChanged(QListViewItem *);
  void handleRightClicked(QListViewItem *,const QPoint&,int);
  void handleDoubleClicked(QListViewItem *);

private:
  // member functions
  DalListView(const DalListView&);            // copy constructor (disabled)
  DalListView& operator=(const DalListView&); // assignment (disabled)
  DalListViewItem* convert(QListViewItem*);   // converter!

  // member data
  bool           _tree;
  Type           _type;

  Folder*        _root;
};



#endif
