// -*-C++-*-
//
// File:      DalListViewDataSet.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue Jul 25 13:21:17 MET DST 2000

#include "DalListViewDataSet.h"
#include "DalListViewFolder.h"
#include "DalListViewTable.h"
#include "DalListViewArray.h"
#include "DataSetFile.h"
#include "IconLibrary.h"

#include <Dal.h>

#include <qpixmap.h>
#include <qfileinfo.h>

#include <iostream>

static const QPixmap* DataSetXpm=0;

DalListViewDataSet::DalListViewDataSet(DataSetFile* dataSetFile,
			       DalListViewFolder* parent,
				       const char* name) :
  DalListViewAttributable(0,parent,name),
  _dataSetFile(dataSetFile),_parent(parent)
{
  _init();
}

DalListViewDataSet::DalListViewDataSet(DataSetFile* dataSetFile,
			       QListView* parent,
			       const char* name) :
  DalListViewAttributable(0,parent,name),
  _dataSetFile(dataSetFile),_parent(0)
{
  _init();
}

DalListViewItem* DalListViewDataSet::clone(QListView* parent)
{
  return new DalListViewDataSet(_dataSetFile,parent,"Cloned");
}

void DalListViewDataSet::_init()
{
  if (!DataSetXpm) DataSetXpm=&IconLibrary::instance()->icon("DataSet.xpm");

  setText(0,_dataSetFile->name());
  setPixmap(0,*DataSetXpm);
  setText(1,"DataSet");
}

DalListViewDataSet::~DalListViewDataSet()
{
}

void DalListViewDataSet::setOpen( bool o )
{
  if ( o && !childCount() ) {
    DataSet* dataSet=_dataSetFile->dataSet();
    _attributable=dataSet;

    unsigned nblocks = dataSet->blocks();
    for(unsigned i=0; i<nblocks; i++) {
      switch (dataSet->block(i)->type()) {
      case Block::TableT: 
	new DalListViewTable(dataSet->table(i),this);
	break;;
      case Block::ArrayT:
	new DalListViewArray(dataSet->array(i),this);
	break;;
      }
    }
  }
  QListViewItem::setOpen( o );
}

void DalListViewDataSet::setup()
{
  setExpandable(true);
  QListViewItem::setup();
}

QString DalListViewDataSet::qualifiedName()
{
  return QString(_dataSetFile->qualifiedName());
}

void DalListViewDataSet::openChildren(QListView* v)
{
    v->clear();
    DataSet* dataSet=_dataSetFile->dataSet();
    unsigned nblocks = dataSet->blocks();
    for(unsigned i=0; i<nblocks; i++) {
      switch (dataSet->block(i)->type()) {
      case Block::TableT: 
	new DalListViewTable(dataSet->table(i),v);
	break;;
      case Block::ArrayT:; // do nothing yet
	new DalListViewArray(dataSet->array(i),v);
	break;;
      }
    }
    _attributable=dataSet;
    DalListViewAttributable::openChildren(v);
}
