// -*-C++-*-
//
// File:      DalListViewFolder.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue Jul 25 13:21:17 MET DST 2000

#include "DalListViewFolder.h"
#include "DalListViewDataSet.h"
#include "DalListViewAnyFile.h"
#include "IconLibrary.h"

#include <qapplication.h> // cursor
#include <qpixmap.h>

static const QPixmap* FolderOpenXpm=0;
static const QPixmap* FolderClosedXpm=0;

DalListViewFolder::DalListViewFolder(Folder* folder,
			       DalListViewFolder* parent,
			       const char* name)
  : DalListViewItem(parent,name),_folder(folder),_parent(parent)
{
  _init();
}

DalListViewFolder::DalListViewFolder(Folder* folder,
			       QListView* parent,
			       const char* name)
  :DalListViewItem(parent,name),_folder(folder),_parent(0)
{
  _init();
}

DalListViewItem* DalListViewFolder::clone(QListView* parent)
{
  return new DalListViewFolder(_folder,parent,"Cloned");
}

void DalListViewFolder::_init()
{
  if (!FolderOpenXpm) FolderOpenXpm=&IconLibrary::instance()->icon("FolderOpen.xpm");
  if (!FolderClosedXpm) FolderClosedXpm=&IconLibrary::instance()->icon("FolderClosed.xpm");

  setText(0,_folder->folderName());
  setPixmap(0,*FolderClosedXpm);
  setText(1,"Folder");
}

DalListViewFolder::~DalListViewFolder()
{
}

void DalListViewFolder::setOpen( bool o )
{
  if ( o && !childCount() ) {
    QApplication::setOverrideCursor( waitCursor ); // this might take time

    QListIterator<Folder> it( _folder->folders() );
    Folder* f;
    while ( (f=it.current()) != 0) {
      ++it;
      new DalListViewFolder(f,this);
      //insertItem(new DalListViewFolder(f,this));
    }

    QListIterator<DataSetFile> itD( _folder->dataSets() );
    DataSetFile* d;
    while ( (d=itD.current()) != 0) {
      ++itD;
      new DalListViewDataSet(d,this);
      //insertItem(new DalListViewFolder(f,this));
    }

    if (!childCount()) setExpandable(false);

    QApplication::restoreOverrideCursor();	// restore original cursor
  }

  /* PATCH 1.28.4: do not override pretty pixmaps!*/
  const QPixmap* mypix=pixmap(1);
  if (mypix == FolderOpenXpm || mypix == FolderClosedXpm) {
    if (o) setPixmap(0,*FolderOpenXpm);
    else setPixmap(0,*FolderClosedXpm);
  }
  QListViewItem::setOpen( o );
}

void DalListViewFolder::setup()
{
  if (_folder->readable()) setExpandable(true);
  else {
    setExpandable(false);
  }
  QListViewItem::setup();
}

QString DalListViewFolder::qualifiedName()
{
  return _folder->qualifiedName();
}

void DalListViewFolder::openChildren(QListView* v)
{

  if (!v) return;
  v->clear();

  QApplication::setOverrideCursor( waitCursor ); // this might take time
  { // show folders
    QListIterator<Folder> it(_folder->folders());
    Folder* f;
    while ( (f=it.current()) != 0) {
      ++it;
      new DalListViewFolder(f,v);
    }
  }
  { // show sets
    QListIterator<DataSetFile> it(_folder->dataSets());
    DataSetFile* s;
    while ( (s=it.current()) != 0) {
      ++it;
      new DalListViewDataSet(s,v);
    }
  }
  { // show files
    QListIterator<AnyFile> it(_folder->files());
    AnyFile* f;
    while ( (f=it.current()) != 0) {
      ++it;
      new DalListViewAnyFile(f,v);
    }
  }
  QApplication::restoreOverrideCursor();	// restore original cursor
}
