// -*-C++-*-
//
// File:      DalViewColumnContents.cc
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Mon Jul 31 12:42:43 MET DST 2000

#include "DalViewColumnContents.h"
#include <Dal.h>


DalViewColumnContents::DalViewColumnContents(Column* column,
				   QWidget* parent, const char* name) : 
  QMultiLineEdit(parent,name),
  _column(column),
  _done(false)
{
  setReadOnly(true);
  setText("<contents not loaded>");
}

DalViewColumnContents::~DalViewColumnContents()
{
}

void DalViewColumnContents::showData()
{
  if (_done) return;
  clear();
  ColumnData* d = _column->data();
  unsigned nrows = _column->rows();

  // Display the data, according to type
  switch(_column->dataType())
    {
    case Dal::Bool: {
      bool8* data = d->boolData();
      for(unsigned k=0; k<nrows; k++)
	{
	  append(QString().setNum(k) + "\t" + 
		 QString().setNum(data[k]));
	}
      break;
    }
    case Dal::Int8: {
      int8* data = d->int8Data();
      for(unsigned k=0; k<nrows; k++)
	{
	  append(QString().setNum(k) + "\t" + 
		 QString().setNum((int)data[k]));
	}
      break;
    }
    case Dal::Int16: {
      int16* data = d->int16Data();
      for(unsigned k=0; k<nrows; k++)
	{
	  append(QString().setNum(k) + "\t" + 
		 QString().setNum(data[k]));
	}
	    break;
    }
    case Dal::Int32: {
      int32* data = d->int32Data();
      for(unsigned k=0; k<nrows; k++)
	    {	
	      append(QString().setNum(k) + "\t" + 
		     QString().setNum(data[k]));
 	    }
      break;
    }
    case Dal::Real32: {
      real32* data = d->real32Data();
      for(unsigned k=0; k<nrows; k++)
	{
	  append(QString().setNum(k) + "\t" + 
		     QString().setNum(data[k]));
	}
      break;
    }
    case Dal::Real64: {
      real64* data = d->real64Data();
      for(unsigned k=0; k<nrows; k++)
	{
	  append(QString().setNum(k) + "\t" + 
		 QString().setNum(data[k]));
	}
      break;
    }
    case Dal::DString: {
      //char* data = d->stringData();
      // uint size = d->elements();
      
  	    for(unsigned k=0; k<nrows; k++)
	      {
		append(QString().setNum(k) + "\t" + 
		       QString("NOT IMPLEMENTED!"));
		//QString(data + k*size, size));
	      }
	    break;
    }
    case Dal::Uint16: {
      uint16* data = d->uint16Data();
      for(unsigned k=0; k<nrows; k++)
	{
	  append(QString().setNum(k) + "\t" + 
		 QString().setNum(data[k]));
	}
      break;
    }
    case Dal::Uint32: {
      uint32* data = d->uint32Data();
      for(unsigned k=0; k<nrows; k++)
	{
	  append(QString().setNum(k) + "\t" + 
		 QString().setNum(data[k]));
	}
      break;
    }
    }
  delete d;
  _done=true;
}
