// -*-C++-*-
//
// File:      DataSetBrowser.h
// Author:    Jorgo Bakker (jbakker@astro.estec.esa.nl)
// Generated: Tue Jul 25 16:36:35 MET DST 2000

#ifndef DataSetBrowser_h
#define DataSetBrowser_h

#include "DalListViewable.h"

#include <qmainwindow.h>

#include <vector>
#include <string>

class DalListView;
class DalListViewItem;
class DalQuickView;
class DalSelectionView;
class GuiPreferences;
class QToolBar;
class QSplitter;
class QPushButton;

class DataSetBrowserProperties;

class DataSetBrowser : public QMainWindow
{
  Q_OBJECT
public:
  enum ExitCode { Rejected, Accepted };

  DataSetBrowser(QWidget* parent=0, const char* name=0);
  virtual ~DataSetBrowser();

  vector<string> selection();
  void setSelection(const vector<string>&);
  

  // returns 0 (Rejected) or 1 (Accepted)
  int exec();

  void openQualifiedName(const QString&,bool root,bool open=false);
  void setSelectable(DalListViewable::Type);
  void setMultiSelection(bool b);

signals:

public  slots:
  void gotoHome();
  void gotoOdf();
  void gotoCcf();
  void gotoCwd();
  
  void setPreferences(GuiPreferences*);

protected slots:
  virtual void accept();
  virtual void reject();
  virtual void relative(bool);
  
private slots:
  void message(const QString&);

protected:
  // only derived classes can use these
  void  closeEvent(QCloseEvent *);
  void  finish(ExitCode);
private:
  // member functions
  DataSetBrowser(const DataSetBrowser&);            // copy constructor (disabled)
  DataSetBrowser& operator=(const DataSetBrowser&); // assignment (disabled)

  // member data
  DalListView*      _tree;
  DalListView*      _contents;
  DalQuickView*     _quickView;
  DalSelectionView* _selection;
  QSplitter*        _splitWindow;
  QToolBar*         _tools;

  QPushButton*      _ok;
  QPushButton*      _cancel;

  DalListViewItem*  _home;
  DalListViewItem*  _ccf;
  DalListViewItem*  _odf;
  DalListViewItem*  _cwd;

  ExitCode          _result;

  static DataSetBrowserProperties* _property;
};



#endif
