/*****************************************************************************
 *
 *  IntParamWidget.cc                           XMM Science Analysis Subsystem
 *
 *  Widget for editting integer parameters
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: IntParamWidget.cc,v 1.4 1999/06/29 14:09:39 jbrumfit Exp $
 *
 *****************************************************************************/

#include "IntParamWidget.h"  // Application headers
#include "IntParameter.h"
#include <Optional.h>

#include <iostream.h>        // C++ headers
#include <string>

#include <qtooltip.h>        // Qt headers


//================================================================
//  Class IntParamWidget
//================================================================

IntParamWidget::IntParamWidget(IntParameter* par, QWidget* parent)
  : IntegerEdit(parent)
{
    _par = par;
    Optional<int> min = _par->minValue();
    Optional<int> max = _par->maxValue();
    string prompt     = _par->prompt();

    if(prompt.length()>0)
        QToolTip::add(this,prompt.c_str());
    if(min.isDefined())
        setMin(min);
    if(max.isDefined())
        setMax(max);
    connect(this, SIGNAL(valueChanged(int)), 
            this, SLOT(valueChanged(int)));

    updateView();
}

IntParamWidget::~IntParamWidget()
{
    _par->deleteView();
}

void IntParamWidget::valueChanged(int value)
{
    _par->setValue(value);
}

void IntParamWidget::updateView()
{
    setValue(_par->intValue());
}
