/*****************************************************************************
 *
 *  ParamWidget.cc                              XMM Science Analysis Subsystem
 *
 *  Widgets for editting parameters
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: ParamWidget.cc,v 1.7 1999/06/25 13:57:23 jbrumfit Exp $
 *
 *****************************************************************************/

#include "Parameter.h"         // Application headers
#include "ParamWidget.h"
#include "BoolParamWidget.h"
#include "IntParamWidget.h"
#include "RealParamWidget.h"
#include "AngleParamWidget.h"
#include "TimeParamWidget.h"
#include "StringParamWidget.h"
#include "StringChoiceParamWidget.h"
#include "FileNameParamWidget.h"
#include "BoolListParamWidget.h"
#include "IntListParamWidget.h"
#include "RealListParamWidget.h"
#include "AngleListParamWidget.h"
#include "TimeListParamWidget.h"
#include "StringListParamWidget.h"
#include "FileNameListParamWidget.h"
#include "SpecialStringParamWidgets.h"
#include <errstr.h>

#include <iostream.h>          // C++ headers
#include <string>
#include <qwidget.h>

class BoolParameter;


//================================================================
//  Abstract class ParamWidget
//================================================================

/*** Virtual constructor ***/

QWidget* ParamWidget::makeWidget(Parameter* param, QWidget* parent, 
				 const char* label)
{
    QWidget* pw = 0;

    switch(param->getType()) {

    case Parameter::Bool: {
      BoolParamWidget* w = 
	  new BoolParamWidget((BoolParameter*)param, parent, label);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::Int: {
      IntParamWidget* w = 
	  new IntParamWidget((IntParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::Real: {
      RealParamWidget* w = 
	  new RealParamWidget((RealParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::Angle: {
      AngleParamWidget* w = 
	  new AngleParamWidget((AngleParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    } 
    case Parameter::Time: {
      TimeParamWidget* w = 
	  new TimeParamWidget((TimeParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::String: {
      StringParamWidget* w = 
	  new StringParamWidget((StringParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::StringChoice: {
      StringChoiceParamWidget* w = 
	  new StringChoiceParamWidget((StringChoiceParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::FileName: {
      FileNameParamWidget* w = 
	  new FileNameParamWidget((FileNameParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::Directory: {
      DirectoryParamWidget* w = 
	  new DirectoryParamWidget((DirectoryParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::DataSet: {
      DataSetParamWidget* w = 
	  new DataSetParamWidget((DataSetParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::Block: {
      BlockParamWidget* w = 
	  new BlockParamWidget((BlockParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::Table: {
      TableParamWidget* w = 
	  new TableParamWidget((TableParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::Array: {
      ArrayParamWidget* w = 
	  new ArrayParamWidget((ArrayParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::Column: {
      ColumnParamWidget* w = 
	  new ColumnParamWidget((ColumnParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::BoolList: {
      BoolListParamWidget* w = 
	  new BoolListParamWidget((BoolListParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::IntList: {
      IntListParamWidget* w = 
	  new IntListParamWidget((IntListParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::RealList: {
      RealListParamWidget* w = 
	  new RealListParamWidget((RealListParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::AngleList: {
      AngleListParamWidget* w = 
	  new AngleListParamWidget((AngleListParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::TimeList: {
      TimeListParamWidget* w = 
	  new TimeListParamWidget((TimeListParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::StringList: {
      StringListParamWidget* w = 
	  new StringListParamWidget((StringListParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::FileNameList: {
      FileNameListParamWidget* w = 
	  new FileNameListParamWidget((FileNameListParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::StringChoiceList: {
      StringChoiceListParamWidget* w = 
	  new StringChoiceListParamWidget((StringChoiceListParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::DirectoryList: {
      DirectoryListParamWidget* w = 
	  new DirectoryListParamWidget((DirectoryListParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::DataSetList: {
      DataSetListParamWidget* w = 
	  new DataSetListParamWidget((DataSetListParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::BlockList: {
      BlockListParamWidget* w = 
	  new BlockListParamWidget((BlockListParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::TableList: {
      TableListParamWidget* w = 
	  new TableListParamWidget((TableListParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::ArrayList: {
      ArrayListParamWidget* w = 
	  new ArrayListParamWidget((ArrayListParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    case Parameter::ColumnList: {
      ColumnListParamWidget* w = 
	  new ColumnListParamWidget((ColumnListParameter*)param, parent);
      param->setView(w);
      pw = w;
      break;
    }
    default:
      errstr << "Parameter '" << param->name()
	     << "' has unknown type '" << param->getTypeName() << '\''
	     << Sas::warning(string("UnknownParType"));
      break;
    }
    return pw;
}

