/*****************************************************************************
 *
 *  PopupParamListWidget.cc                     XMM Science Analysis Subsystem
 *
 *  String-list widget which pops up a browser dialog
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: PopupParamListWidget.cc,v 1.4 2000/09/14 13:58:13 jbakker Exp $
 *
 *****************************************************************************/

#include "PopupParamListWidget.h"      // Application headers
#include "StringListParameter.h"

#include <iostream.h>                  // C++ headers
#include <string>
#include <strstream.h>

#include <qtooltip.h>                  // Qt headers
#include <qpushbutton.h>
#include <qwidget.h>


//================================================================
//  Abstract class PopupParamListWidget
//================================================================

PopupParamListWidget::PopupParamListWidget(StringListParameter* par, QWidget* parent)
  : QWidget(parent)
{
    _itype = DalListViewable::None;

    _par = par;
    string prompt = _par->prompt();

    _edit = new StringListEdit(this);

    if(prompt.length()>0)
        QToolTip::add(_edit,prompt.c_str());

    connect(_edit, SIGNAL(valueChanged()), this, SLOT(valueChanged()));

    _button = new QPushButton(this);
    _button->setAutoDefault(false);
    _button->setText("..");
    QToolTip::add(_button,(string("Select ") + _par->getTypeName() + "...").c_str());

    connect(_button, SIGNAL(clicked()),this, SLOT(popupDialog()));

    updateView();
}

PopupParamListWidget::~PopupParamListWidget()
{
    _par->deleteView();
}

void PopupParamListWidget::resizeEvent(QResizeEvent*)
{
    int w = width();
    int h = height();
    int bw = 16;
    
    _edit->setGeometry(0,0,w-bw,h);
    _button->setGeometry(w-bw,0,bw,h);
}

void PopupParamListWidget::valueChanged()
{
    _par->setValue(_edit->value());
}

void PopupParamListWidget::updateView()
{
    _edit->setValue(_par->stringListValue());
}

void PopupParamListWidget::setEnabled(bool enable)
{
    _edit->setEnabled(enable);
    _button->setEnabled(enable);
}

void PopupParamListWidget::setValue(const vector<string>& value)
{
    _edit->setValue(value);
}
