/*****************************************************************************
 *
 *  RealListParamWidget.cc                      XMM Science Analysis Subsystem
 *
 *  Widgets for editting real list parameters
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: RealListParamWidget.cc,v 1.4 1999/06/29 14:09:45 jbrumfit Exp $
 *
 *****************************************************************************/

#include "RealListParamWidget.h"  // Application headers
#include "RealListParameter.h"
#include <Optional.h>

#include <iostream.h>            // C++ headers
#include <string>
#include <vector>

#include <qtooltip.h>            // Qt headers


//================================================================
//  Class RealListParamWidget
//================================================================

RealListParamWidget::RealListParamWidget(RealListParameter* par, QWidget* parent)
  : DoubleListEdit(parent)
{
    _par = par;
    Optional<double> min = _par->minValue();
    Optional<double> max = _par->maxValue();
    string prompt = _par->prompt();

    if(prompt.length()>0)
        QToolTip::add(this, prompt.c_str());
    if(min.isDefined())
        setMin(min);
    if(max.isDefined())
        setMax(max);
    connect(this, SIGNAL(valueChanged()), this, SLOT(valueChanged()));

    updateView();
}

RealListParamWidget::~RealListParamWidget()
{
    _par->deleteView();
}

void RealListParamWidget::valueChanged()
{
    _par->setValue(value());
}

void RealListParamWidget::updateView()
{
    setValue(_par->realListValue());
}
