/*****************************************************************************
 *
 *  StringChoiceParamWidget.cc                  XMM Science Analysis Subsystem
 *
 *  Widget for selecting from a set of strings
 *
 *  (c) 1998  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: StringChoiceParamWidget.cc,v 1.5 1999/07/20 09:00:13 jbrumfit Exp $
 *
 *****************************************************************************/

#include "StringChoiceParamWidget.h"  // Application headers
#include "StringChoiceParameter.h"

#include <iostream.h>                 // C++ headers
#include <string>
#include <qcombobox.h>

#include <qtooltip.h>                 // Qt headers


//================================================================
//  Class StringChoiceParamWidget
//================================================================

StringChoiceParamWidget::StringChoiceParamWidget(StringChoiceParameter* par,
						 QWidget* parent)
  : QComboBox(parent)
{
    _par = par;
    string prompt = _par->prompt();
    const list<string> choices = _par->getChoices();

    // Add each choice to the menu
    list<string>::const_iterator it = choices.begin();
    while(it != choices.end())
        insertItem((*it++).c_str());

    if(prompt.length()>0)
        QToolTip::add(this,prompt.c_str());

    connect(this, SIGNAL(activated(const QString&)), 
 	    this, SLOT(valueChanged(const QString&)));

    updateView();
}

StringChoiceParamWidget::~StringChoiceParamWidget()
{
    _par->deleteView();
}

void StringChoiceParamWidget::valueChanged(const QString& value)
{
    _par->setValue(value);
}

void StringChoiceParamWidget::updateView()
{
    setItem((_par->stringValue()).c_str());
    emit activated(currentItem());
}

/*
 *  Set current item to that matching string.
 *  If the string is missing, then add it.
 */

void StringChoiceParamWidget::setItem(const char* string)
{
    QString str(string);

    int n = count();
    int i = 0;

    while(i<n && !(str == text(i)))
        i++;

    if(i == n)
        insertItem(string);

    setCurrentItem(i);
}
