/*****************************************************************************
 *
 *  TimeListParamWidget.cc                     XMM Science Analysis Subsystem
 *
 *  Widgets for editting angle list parameters
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: TimeListParamWidget.cc,v 1.1 1999/12/06 15:28:38 jbrumfit Exp $
 *
 *****************************************************************************/

#include "TimeListParamWidget.h"
#include <iostream.h>

#include <qtooltip.h>


//================================================================
//  Class TimeListParamWidget
//================================================================

TimeListParamWidget::TimeListParamWidget(TimeListParameter* par,
					   QWidget* parent)
  : MultiTimeListEdit(parent)
{
    _par = par;
    Optional<double> min = _par->minValue();
    Optional<double> max = _par->maxValue();
    string prompt = _par->prompt();

    if(prompt.length()>0)
        QToolTip::add(this, prompt.c_str());
    if(min.isDefined())
        setMin(min);
    if(max.isDefined())
        setMax(max);
    connect(this, SIGNAL(valueChanged()), this, SLOT(valueChanged()));
    connect(this, SIGNAL(modeChanged(TimeFormatter::TimeMode)),
            SLOT(modeChanged(TimeFormatter::TimeMode)));

    updateView();
}

TimeListParamWidget::~TimeListParamWidget()
{
    _par->deleteView();
}

void TimeListParamWidget::valueChanged()
{
    _par->setValue(value());
}

void TimeListParamWidget::updateView()
{
    setMode(_par->getMode());
    setValue(_par->realListValue());
}

void TimeListParamWidget::modeChanged(TimeFormatter::TimeMode mode)
{
    _par->setMode(mode);
}
