/*****************************************************************************
 *
 *  AlertDialog.cc                              XMM Science Analysis Subsystem
 *
 *  Alert dialog for warning messages
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: AlertDialog.cc,v 1.2 1999/07/20 08:10:31 jbrumfit Exp $
 *
 *****************************************************************************/

#include "AlertDialog.h"           // Application headers
#include "OnDemandScrollView.h"

#include <iostream.h>              // C+ headers

#include <qcheckbox.h>             // Qt headers
#include <qlayout.h>
#include <qpixmap.h>
#include <qmessagebox.h>
#include <qwindowdefs.h>
#include <qlabel.h>
#include <qpushbutton.h>
#include <qfont.h>


//================================================================
//  Class AlertDialog
//================================================================

/*** Create a dialog [ STATIC ] ***/

void AlertDialog::alert(QWidget* parent,
			const char* caption,
			const char* text,
			QMessageBox::Icon type,
			const char* code)
{
    if(AlertDialog::isShowable(code))
    {
        AlertDialog alert(parent,caption,text,type,code);
	alert.exec();
    }
}


/*** Constructor ***/

AlertDialog::AlertDialog(QWidget* parent,
			 const char* caption,
			 const char* text,
			 QMessageBox::Icon type,
			 const char* code)
  : QDialog(parent, caption, true), _code(code)
{
    // Maximum size of scroller when dialog is first opened

    int maxWidth  = 700;
    int maxHeight = 500;
    const int margin = 10;     // Margin around text

    setCaption(caption);

    _noShow.setAutoDelete(true);


    /*** Create a caption ***/

    _caption = 0;
    if(caption)
    {
        _caption = new QLabel(caption,this);
	QFont f("Helvetica", 12, QFont::Bold);
	_caption->setFont(f);
	_caption->setFixedSize(_caption->sizeHint());
    }


    /*** Create an icon to indicate the types of message ***/

    QLabel* iconLabel = 0;
    if(type != QMessageBox::NoIcon)
    {
        iconLabel = new QLabel(this);
	iconLabel->setPixmap(QMessageBox::standardIcon(type,MotifStyle));
	iconLabel->setFixedSize(iconLabel->sizeHint());
    }

    
    /*** Create a label for the message and place it in a scroll frame ***/

    OnDemandScrollView* _scroller = new OnDemandScrollView(this);
    _scroller->setFrameStyle(QFrame::Box|QFrame::Raised);
    _scroller->setMaximumPreferredSize(maxWidth,maxHeight);

    _message = new QLabel(text, _scroller->viewport());
    _message->setMargin(margin);
    _message->adjustSize();

    _scroller->setContents(_message);

    
    /*** If 'code' is specified, add a checkbox to disable repeat warnings ***/

    _checkbox = 0;
    if(code)
    {
        _checkbox = new QCheckBox("Don't show this warning again",this);
	_checkbox->setFixedSize(_checkbox->sizeHint());
    }


    /*** Create the "Ok" button ***/

    _okButton = new QPushButton("Ok",this);
    _okButton->setFixedSize(50,20);
    connect(_okButton,SIGNAL(clicked()),SLOT(close()));


    /*** Geometry management ***/

    QBoxLayout* vbox = new QVBoxLayout(this,10);
    QBoxLayout* hbox = new QHBoxLayout();
    if(caption)
        vbox->addWidget(_caption);

    vbox->addLayout(hbox);

    if(iconLabel)
        hbox->addWidget(iconLabel,0);
    hbox->addWidget(_scroller,0);
    vbox->addSpacing(5);
    if(_checkbox)
    {
        vbox->addWidget(_checkbox);
	vbox->addSpacing(5);
    }
    vbox->addWidget(_okButton,0);

    adjustSize();
}


/*** Close the dialog [ private slot ] ***/

void AlertDialog::close()
{
    if(_checkbox && _checkbox->isChecked())
        _noShow.append(_code);
    
    accept();
}


/*** Test whether the message should be shown ***/

bool AlertDialog::isShowable(const char* code)
{
    return _noShow.find(code) < 0;	    
}


/*** Reset dialog so that no messages are ignored [ static ] ***/

void AlertDialog::reset()
{
    _noShow.clear();
}

QStrList AlertDialog::_noShow;

