/*****************************************************************************
 *
 *  AlertDialog.h                               XMM Science Analysis Subsystem
 *
 *  Alert dialog for warning messages
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: AlertDialog.h,v 1.1 1999/05/10 12:14:51 jbrumfit Exp $
 *
 *****************************************************************************/

#ifndef ALERTDIALOG_H
#define ALERTDIALOG_H

#include <qdialog.h>          // Qt headers
#include <qstrlist.h>
#include <qstring.h>
#include <qmessagebox.h>

class QWidget;
class QPushButton;
class QCheckBox;
class QLabel;


//================================================================
//  Class AlertDialog
//
//  An alert dialog for warning/error messages.
//
//  A unique 'code' may be specified, in which case the dialog provides
//  a checkbox to disable repeat warnings with the same code. The class 
//  maintains a static list of messages which have been disabled in this 
//  way.
//
//  The optional caption is displayed as the window title. It is repeated
//  within the dialog for window managers which do not show dialog frames
//  (e.g. 'fvwm').
//
//  Example:
//
//     AlertDialog::alert(this,                             // Parent widget
//                        "Caption",                        // Dialog title
//                        QMessageBox::NoIcon,              // Message type
//                        "OhNo",                           // Unique code
//		          "A message\nwith several lines"); // The message
//
//  The dialog adds scroll bars if the message is too large to be accomodated
//  in a reasonable size dialog. An AlertDialog may be resized and will 
//  automatically acquire scroll bars, if needed.
//
//================================================================

class AlertDialog : public QDialog
{
    Q_OBJECT

public:
    static void alert(QWidget* parent,                            // Parent widget
		      const char* caption=0,                      // Dialog title
		      const char* text=0,                         // Message text
		      QMessageBox::Icon type=QMessageBox::NoIcon, // Message type
		      const char* code=0);                        // Unique code

    static bool isShowable(const char* code);
    static void reset();

private slots:
    void close();

protected:
    AlertDialog(QWidget* parent,
		const char* caption=0,
		const char* text=0,
		QMessageBox::Icon type=QMessageBox::NoIcon,
		const char* code=0);

private:
    // Disabled copy constructor and operator=
    AlertDialog(const AlertDialog&) : QDialog() {}
    AlertDialog& operator=(const AlertDialog&) {return *this;}

    // Member data
    QPushButton* _okButton;
    QCheckBox*   _checkbox;
    QLabel*      _caption;
    QLabel*      _message;
    QString      _code;

    static QStrList _noShow;       // List of codes for "don't show again"
};

#endif
