/*****************************************************************************
 *
 *  BoolListEdit.cc                             XMM Science Analysis Subsystem
 *
 *  Qt widget for editing lists
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: BoolListEdit.cc,v 1.3 2000/09/14 13:58:13 jbakker Exp $
 *
 *****************************************************************************/

#include <iostream.h>            // C++ headers
#include <strstream.h>
#include <vector>
#include <string>

#include <qwidget.h>             // Qt headers
#include <qregexp.h>
#include <qstring.h>

#include "BoolListEdit.h"     // Application headers


//================================================================
//  Class BoolListEdit
//================================================================

/*** Constructor ***/

BoolListEdit::BoolListEdit(QWidget *parent, const char *name)
  : ValidatedEdit(parent, name)
{
    setTextToValue();              // Update widget
}


/***  Return the latest valid value ***/

vector<int> BoolListEdit::value() const
{
    return _value;
}


/*** Set the value and update display. ***/

void BoolListEdit::setValue(vector<int> value)
{
    if(value != _value)
    {
        _value = value;
	setTextToValue();          // Update widget
    }
}


/*** Set widget text to current value ***/

void BoolListEdit::setTextToValue()
{
    QString str;
    vector<int>::const_iterator it1 = _value.begin();
    while(it1 != _value.end())
    {
        if(*it1++)
	    str.append("1");
	else
	    str.append("0");
    }
    setText(str);
}


/*** Parse string and set value ***/

void BoolListEdit::setValueToText()
{
    bool ok = true;
    vector<int> values;
 
    QString txt=text();
    const char* p = txt.latin1();

    while(p)
    {
      char c = *p++;
      if (!c) break;

        switch(c)
        {
	case '0':
	case 'n':
	case 'f':
	case 'N':
	case 'F':
	    values.push_back(0);
	    break;

	case '1':
	case 'y':
	case 't':
	case 'Y':
	case 'T':
	    values.push_back(1);
	    break;

	default:
	    ok = false;
	    break;
	}
    }

    if(ok && (values != _value))
    {
        _value = values;
	emit valueChanged();
    }
}


/*** Test the hard constraint - valid syntax ***/

bool BoolListEdit::isValid()
{
    QRegExp expr("[01yntfYNTF]*");

    QString s = text();
    bool ok = true;
    int len = 0;
    ok &= expr.match(s, 0, &len) == 0;
    ok &= len == (int)s.length();

    return ok;
}


/*** Test the soft constraint - value in range ***/

bool BoolListEdit::isInRange()
{
    return true;
}
