/*****************************************************************************
 *
 *  DoubleEdit.cc                               XMM Science Analysis Subsystem
 *
 *  Qt widget for editing doubles
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: DoubleEdit.cc,v 1.1 1999/06/24 09:24:23 jbrumfit Exp $
 *
 *****************************************************************************/

#include <values.h>              // C headers

#include <iostream.h>            // C++ headers

#include <qwidget.h>             // Qt headers
#include <qregexp.h>

#include "DoubleEdit.h"         // Application headers


//================================================================
//  Class DoubleEdit
//================================================================

/*** Constructor ***/

DoubleEdit::DoubleEdit(QWidget *parent, const char *name, double value)
  : ValidatedEdit(parent, name)
{
    _value = value;
    setRange(-MAXDOUBLE, MAXDOUBLE);

    setTextToValue();
}


/*** Return the latest valid value ***/

double DoubleEdit::value() const
{
    return _value;
}


/*** Set the value and update display ***/

void DoubleEdit::setValue(double value)
{
    if(value != _value)
    {
        _value = value;
        setTextToValue();    // Update the widget
    }
}


/*** Set widget text to current value ***/

void DoubleEdit::setTextToValue()
{
    QString s;
    s.setNum(_value);
    setText(s);
}


/*** Parse string and set value ***/

void DoubleEdit::setValueToText()
{
    QString buff(text());
    bool ok = false;
    double val = buff.toDouble(&ok);
    if(ok && _value != val)
    {
        _value = val;
	emit valueChanged(_value);
    }
}


/*** Test the hard constraint - valid syntax ***/

bool DoubleEdit::isValid()
{
    QRegExp expr("^ *-?[0-9]*[.]?[0-9]*[Ee]?[+-]?[0-9]* *$");
    int len = 0;
    bool ok = expr.match(text(), 0, &len) == 0;
    return ok && (len == (int)QString(text()).length());
}


/*** Test the soft constraint - value in range ***/

bool DoubleEdit::isInRange()
{
    // Note: Underflow is not considered to be out-of-range

    QString buff(text());
    bool ok = false;
    double val = buff.toDouble(&ok);
    return ok && isValidValue(val);
}
