/*****************************************************************************
 *
 *  GuiPreferences.cc                              XMM Science Analysis Subsystem
 *
 *  Application preferences
 *
 *  (c) 1999 ESA  -  Written by Jon Brumfitt, Aurora
 *  (c) 2000 ESA  -  Rewritten by Jorgo Bakker, BSC
 *
 *
 *****************************************************************************/

#include "GuiPreferences.h"           // Appliaction headers
#include "ParamInfoReader.h"
#include "XpiInfoReader.h"
#include "System.h"
#include <qdir.h>

class ParameterEnv : public map< string, string > {};

//================================================================
//  Class GuiPreferences
//================================================================

/*** Static instance when used as a singleton class ***/

GuiPreferences* GuiPreferences::_instance = 0;


/*** Get the single instance of this class ***/

GuiPreferences* GuiPreferences::instance()
{
  if (!_instance) {
    
    _instance = new GuiPreferences;
    _instance->read("sas/config/preferences");
    _instance->getEnv();
  }
  return _instance;
}


/*** Create a new GuiPreferences object ***/

GuiPreferences::GuiPreferences()
{
  _parameters = 0;
  _env = new ParameterEnv;

  // env[ParName]=envName;
  (*_env)["odf"]="SAS_ODF";
  (*_env)["current"]="CWD";
  (*_env)["ccf"]="SAS_CCF";
  (*_env)["home"]="HOME";
  (*_env)["verbosity"]="SAS_VERBOSITY";
  (*_env)["memory"]="SAS_MEMORY_MODEL";
  //  (*_env)["SuppressWarning"]="SAS_SUPPRESS_WARNING";
}


/*** Create a new GuiPreferences object, initialised from a file ***/

void GuiPreferences::read(const char* prefFileName)
{
  if (_parameters) {
    delete  _parameters;
    _parameters = 0;
  }
  ParamInfoReader* reader = new XpiInfoReader(prefFileName);
  _parameters = reader->getParamInfo();
  delete reader;
}

void GuiPreferences::getEnv()
{
  
  for (ParameterEnv::const_iterator it=_env->begin();it!=_env->end();it++) {
    char* val = ::getenv((*it).second.c_str());
    if (val) {
      Parameter* p = _parameters->parameter((*it).first);
      p->setNewDefault(val);
      p->revertToDefault();
    }
    if ((*it).first == "current") {
      Parameter* p = _parameters->parameter((*it).first);
      p->setNewDefault(QDir::currentDirPath().latin1());
      p->revertToDefault();
    }
  }
}

void GuiPreferences::setEnv(bool force)
{
  for (ParameterEnv::const_iterator it=_env->begin();it!=_env->end();it++) {
    string envName=(*it).second;
    Parameter* p = _parameters->parameter((*it).first);
    string envNew= p->asString();
    if (envNew.length() > 2) {
      if (envNew[0] == envNew[envNew.length()-1] && envNew[0] == '\'')
	envNew=envNew.substr(1,envNew.length()-2);
    }

    // Get current env
    string envOld;
    if (envName == "CWD") envOld=QDir::currentDirPath().latin1();
    else System::getEnv(envName,envOld);

    if (envOld != envNew || force) {
      
      if (envName == "CWD") {
	
	if (QDir::setCurrent (envNew.c_str()))
	  emit environmentChanged(string("cd ") + envNew);
	else {
	  p->setNewDefault(envOld);
	  p->revertToDefault();
	  emit environmentChanged("Could not change dir!");
	}
      }
      else {
	System::setEnv(envName,envNew);
	emit environmentChanged(envName + string("=") + envNew +
				string("; export ") + envName);
      }
    }
  }
}





/*** Return the specfied parameter from preferences ***/

Parameter* GuiPreferences::getParameter(const char* name)
{
    return _parameters->parameter(name);
}

