/*-*-C++-*-********************************************************************
 *
 *  GuiPreferences.h                               XMM Science Analysis Subsystem
 *
 *  Application preferences
 *
 *  (c) 1999 ESA  -  Written by Jon Brumfitt, Aurora
 *  (c) 2000 ESA  -  Rewritten by Jorgo Bakker, BSC
 *
 *
 *****************************************************************************/

#ifndef PREFERENCES_H
#define PREFERENCES_H

#include "Parameter.h"
#include "ParameterInfo.h"

#include <iostream.h>
#include <qobject.h>


//================================================================
//  Class GuiPreferences
//
//  Responsibilities:
//    - load preferences from file
//    - allow initialisation from environment variables
//    - allow setting of environment variables
class ParameterEnv;
class GuiPreferences : public QObject
{
  Q_OBJECT
public:
  // Get the single instance of this class
  static GuiPreferences* instance();
  
  // Return the specfied parameter from preferences
  Parameter*     getParameter(const char* name);
  
  // Return the set of parameters
  ParameterInfo* parameters() { return _parameters; }

  void setEnv(bool force=false);

signals:
  void environmentChanged(const string&);

protected:
  // only derived classes can use these
  GuiPreferences(); // default constructor (disabled)

private:
  // member functions
  GuiPreferences(const GuiPreferences&);            // copy constructor (disabled)
  GuiPreferences& operator=(const GuiPreferences&); // assignment (disabled)
  
  void read(const char* file);

  void getEnv();

  // Member data
  ParameterInfo* _parameters;
  
  static GuiPreferences* _instance;

  ParameterEnv* _env;
};

#endif

