/*****************************************************************************
 *
 *  IntegerEdit.cc                              XMM Science Analysis Subsystem
 *
 *  Qt widget for editing integers
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: IntegerEdit.cc,v 1.3 1999/06/29 14:06:35 jbrumfit Exp $
 *
 *****************************************************************************/

#include <limits.h>              // C headers

#include <iostream.h>            // C++ headers

#include <qwidget.h>             // Qt headers
#include <qregexp.h>

#include "IntegerEdit.h"         // Application headers


//================================================================
//  Class IntegerEdit
//================================================================

/*** Constructor ***/

IntegerEdit::IntegerEdit(QWidget *parent, const char *name, int value)
  : ValidatedEdit(parent, name)
{
    _value = value;
    setRange(INT_MIN, INT_MAX);

    setTextToValue();          // Update the widget
}


// Should be part of "fixup" function
//    int length = strlen(text);
//     if((length == 0) || length == 1 && *text == '-')
//     {
//         if(setFromString("0"))
//             return;
//     }


//***  Return the latest valid value ***/

int IntegerEdit::value() const
{
    return _value;
}


/*** Set the value and update display. ***/

void IntegerEdit::setValue(int value)
{
    if(value != _value)
    {
        _value = value;
	setTextToValue();      // Update the widget
    }
}


/*** Set widget text to current value ***/

void IntegerEdit::setTextToValue()
{
    QString s;
    s.setNum(_value);
    setText(s);
}


/*** Parse string and set value ***/

void IntegerEdit::setValueToText()
{
    QString buff(text());
    bool ok = false;
    int val = buff.toInt(&ok);
    if(ok && _value != val)
    {
        _value = val;
	emit valueChanged(_value);
    }
}


/*** Test the hard constraint - valid syntax ***/

bool IntegerEdit::isValid()
{
    QRegExp expr("^ *-?[0-9]* *$");
    int len = 0;
    bool ok = expr.match(text(), 0, &len) == 0;
    return ok && (len == (int)QString(text()).length());
}


/*** Test the soft constraint - value in range ***/

bool IntegerEdit::isInRange()
{
    QString buff(text());
    bool ok = false;
    int val = buff.toInt(&ok);
    return ok && isValidValue(val);
}

