/*****************************************************************************
 *
 *  IntegerListEdit.cc                          XMM Science Analysis Subsystem
 *
 *  Qt widget for editing lists
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: IntegerListEdit.cc,v 1.3 1999/08/10 14:21:38 jbrumfit Exp $
 *
 *****************************************************************************/

#include <limits.h>              // C headers

#include <iostream.h>            // C++ headers
#include <strstream.h>
#include <vector>

#include <qwidget.h>             // Qt headers
#include <qregexp.h>

#include "IntegerListEdit.h"     // Application headers
#include "StringFns.h"


//================================================================
//  Class IntegerListEdit
//================================================================

/*** Constructor ***/

IntegerListEdit::IntegerListEdit(QWidget *parent, const char *name)
  : ValidatedEdit(parent, name)
{
    setRange(INT_MIN, INT_MAX);
    setTextToValue();              // Update widget
}


/***  Return the latest valid value ***/

vector<int> IntegerListEdit::value() const
{
    return _value;
}


/*** Set the value and update display. ***/

void IntegerListEdit::setValue(vector<int> value)
{
    if(value != _value)
    {
        _value = value;
	setTextToValue();          // Update widget
    }
}


/*** Set widget text to current value ***/

void IntegerListEdit::setTextToValue()
{
    strstream ostr;
    vector<int>::const_iterator it = _value.begin();
    if(it != _value.end())
        ostr << *it++;
    while(it != _value.end())
        ostr << ' ' << *it++;
    ostr << ends;

    setText(ostr.str());
    delete ostr.str();

// ***** Or, use QString::setNum() *****
//
//     QString str;
//     QString s;
//     vector<int>::const_iterator it1 = _value.begin();
//     if(it1 != _value.end())
//         str.setNum(*it1++);
//     while(it1 != _value.end())
//     {
//         s.setNum(*it1++);
// 	   str.append(" ");
// 	   str.append(s);
//     }
//     setText(str);
}


/*** Parse string and set value ***/

void IntegerListEdit::setValueToText()
{
    list<string> tokens = StringFns::splitString(string(text())," ");

    bool ok = true ;
    vector<int> values;
    list<string>::const_iterator it = tokens.begin();
    while(it != tokens.end())
    {
        QString s = (*it++).c_str();
        if(s.length() != 0)     // Don't convert spaces
        {
	    bool ok1= false;
	    int val = s.toInt(&ok1);
	    ok &= ok1;
            values.push_back(val);
        }
    }
    if(ok && (values != _value))
    {
        _value = values;
	emit valueChanged();
    }
}


/*** Test the hard constraint - valid syntax ***/

bool IntegerListEdit::isValid()
{
    QRegExp expr("^-?[0-9]*$");
    bool ok = true;

    list<string> tokens = StringFns::splitString(string(text())," ");
    list<string>::const_iterator it = tokens.begin();
    while(it != tokens.end())
    {
        string s = *it++;

	int len = 0;
	ok &= expr.match(s.c_str(), 0, &len) == 0;
	ok &= len == (int)s.length();
    }
    return ok;
}


/*** Test the soft constraint - value in range ***/

bool IntegerListEdit::isInRange()
{
    bool ok = true;

    list<string> tokens = StringFns::splitString(string(text())," ");
    list<string>::const_iterator it = tokens.begin();
    while(it != tokens.end())
    {
        QString buff = (*it++).c_str();
	bool ok1 = false;
	int val = buff.toInt(&ok1);
	ok &= ok1 && isValidValue(val);
    }
    return ok;
}
