/*****************************************************************************
 *
 *  LongMenu.cc
 *
 *  Qt popup menu with automatic continuation menus
 *
 *  (c) 1998 ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: LongMenu.cc,v 1.2 1999/07/20 08:10:32 jbrumfit Exp $
 *
 *****************************************************************************/

#include "LongMenu.h"             // Application headers

#include <iostream.h>             // C++ headers

#include <qapp.h>                 // Qt headers
#include <qpopupmenu.h>
#include <qpoint.h>


//================================================================
//  Class LongMenu
//================================================================

/*** Constructor ***/

LongMenu::LongMenu(QWidget* parent, const char* name)
  : QPopupMenu(parent,name)
{
    initMetaObject();

    _items      = 0;
    _menus      = 0;

    _menulist[0] = this;

    connect(_menulist[0], SIGNAL(activated(int)),SLOT(itemSelected(int)));

    // Find maximum number of rows that will fit on screen

    int screenHeight = QApplication::desktop()->height();
    int id = QPopupMenu::insertItem("dummy");
    _maxRows = screenHeight / itemHeight(0) - 1;
    removeItem(id);
}


/*** Destructor ***/

LongMenu::~LongMenu()
{
      for(int i=_menus; i>0; i--)
          delete _menulist[i];
}


/*** Add a newitem to the menu ***/

void LongMenu::insertItem (const char * text)
{
    if(_items >= _maxRows) 
    {
	_menus++;
        _items = 0;

        _menulist[_menus] = new QPopupMenu;
	_menulist[_menus-1]->insertItem("More...",_menulist[_menus]);

        connect(_menulist[_menus], SIGNAL(activated(int)), SLOT(itemSelected(int)));
        connect(_menulist[_menus],SIGNAL(aboutToShow()),this, SLOT(getReady()));
    }
    int n = ++_items + _menus * _maxRows;
    _menulist[_menus]->insertItem(text,n);
}

void LongMenu::itemSelected(int id)
{
    const char* text;
    for(int i=0; i<=_menus; i++)
    {
        const char* t = _menulist[i]->text(id);
	if(t)
	    text = t;
    }
    emit selected(text);
}


/*** Reposition the sub-menus before they are displayed ***/

void LongMenu::getReady()
{
    int w = 0;
    for(int i=1; i<_menus+1; i++)
    {
        w += _menulist[i-1]->width();
	_menulist[i]->move(mapToGlobal(QPoint(w,0)));
    }
}


/*** Set the maximum number of rows - Default set by screen height ***/

void LongMenu::setMaxRows(int n)
{
    if(n < _maxRows)
        _maxRows = n;
}
