/*****************************************************************************
 *
 *  MultiAngleEdit.cc                           XMM Science Analysis Subsystem
 *
 *  Qt widget for editing angles, with button to choose mode
 *
 *  (c) 1999 ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: MultiAngleEdit.cc,v 1.5 2000/07/04 09:32:44 jbakker Exp $
 *
 *****************************************************************************/

#include "MultiAngleEdit.h"        // Application headers
#include <qlayout.h>               // Qt headers
#include <qcombobox.h>


//================================================================
//  Class MultiAngleEdit
//================================================================

/*** Constructor ***/

MultiAngleEdit::MultiAngleEdit(QWidget *parent, const char *name)
  : QWidget(parent, name)
{
  _angleEdit = new AngleEdit(this,"angle");
  _combo = new QComboBox(false,this,"AngleMode");
  _combo->insertItem("deg",0);
  _combo->insertItem("DMS",1);
  _combo->insertItem("HMS",2);

  // layout
  QHBoxLayout* box = new QHBoxLayout(this);
  box->addWidget(_angleEdit);
  box->addWidget(_combo);
  box->addStretch(1);

  // signal-slots
  connect(_combo,SIGNAL(activated(int)),
	  this,SLOT(activateMode(int)));
  connect(_angleEdit,SIGNAL(valueChanged(double)),
	  this,SIGNAL(valueChanged(double)));

  // set
  setMode(_angleEdit->mode());
}


/*** Destructor **/

MultiAngleEdit::~MultiAngleEdit()
{
}


/*** Return the latest valid value ***/

double MultiAngleEdit::value() const
{
    return _angleEdit->value();
}


/*** Set the value and update display ***/

void MultiAngleEdit::setValue(double angle)
{
    _angleEdit->setValue(angle);
}


/*** Set enabled state of widget ***/

void MultiAngleEdit::setEnabled(bool enabled)
{
    _angleEdit->setEnabled(enabled);
    _combo->setEnabled(enabled);
}


/*** Set the mode ***/

void MultiAngleEdit::setMode(AngleFormatter::AngleMode mode)
{
  int id=-1;
  switch(mode) {
  case AngleFormatter::Degrees: id=0; break;
  case AngleFormatter::DMS:     id=1; break;
  case AngleFormatter::HMS:     id=2; break;
  }
  if (id > -1) {
    _combo->setCurrentItem(id);
    _angleEdit->setMode(mode);
  }
}

/*** activate settings ***/

void MultiAngleEdit::activateMode(int idx)
{
  AngleFormatter::AngleMode m;
  switch (idx) {
  case 0: m = AngleFormatter::Degrees ; break;
  case 1: m = AngleFormatter::DMS     ; break;
  case 2: m = AngleFormatter::HMS     ; break;
  }
  _angleEdit->setMode(m);
  emit modeChanged(m);
}
