/*****************************************************************************
 *
 *  MultiTimeListEdit.cc                       XMM Science Analysis Subsystem
 *
 *  Qt widget for editing times, with button to choose mode
 *
 *  (c) 1999 ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: MultiTimeListEdit.cc,v 1.2 2000/07/04 09:32:45 jbakker Exp $
 *
 *****************************************************************************/

#include "MultiTimeListEdit.h"    // Application headers
#include <qlayout.h>               // Qt headers
#include <qcombobox.h>


//================================================================
//  Class MultiTimeListEdit
//================================================================

/*** Constructor ***/

MultiTimeListEdit::MultiTimeListEdit(QWidget *parent, const char *name)
  : QWidget(parent, name)
{
  
  // init members
  _timeEdit = new TimeListEdit(this,"timelist");
  _combo = new QComboBox(false,this,"TimeMode");
  _combo->insertItem("MRT",0);
  _combo->insertItem("JD",1);
  _combo->insertItem("MJD",2);
  _combo->insertItem("CAL",3);
  _combo->insertItem("FITS",4);

  // layout
  QHBoxLayout* box = new QHBoxLayout(this);
  box->addWidget(_timeEdit);
  box->addWidget(_combo);


  // signal-slots
  connect(_combo,SIGNAL(activated(int)),
	  this,SLOT(activateMode(int)));
  connect(_timeEdit,SIGNAL(valueChanged()),
	  this,SIGNAL(valueChanged()));

  // set
  setMode(_timeEdit->mode());
}


/*** Destructor **/

MultiTimeListEdit::~MultiTimeListEdit()
{
}


/*** Return the latest valid value ***/

vector<double> MultiTimeListEdit::value() const
{
    return _timeEdit->value();
}


/*** Set the value and update display ***/

void MultiTimeListEdit::setValue(vector<double> time)
{
    _timeEdit->setValue(time);
}


/*** Set enabled state of widget ***/

void MultiTimeListEdit::setEnabled(bool enabled)
{
    _timeEdit->setEnabled(enabled);
    _combo->setEnabled(enabled);
}


/*** Set the mode ***/
void MultiTimeListEdit::setMode(TimeFormatter::TimeMode mode)
{
  int id=-1;
  switch(mode) {
  case TimeFormatter::MRT: id=0; break;
  case TimeFormatter::JD: id=1; break;
  case TimeFormatter::MJD: id=2; break;
  case TimeFormatter::CAL: id=3; break;
  case TimeFormatter::FITS: id=4; break;
  }
  if (id > -1) {
    _combo->setCurrentItem(id);
    _timeEdit->setMode(mode);
  }
}

/*** activate settings ***/

void MultiTimeListEdit::activateMode(int idx)
{
  TimeFormatter::TimeMode m;
  switch (idx) {
  case 0: m = TimeFormatter::MRT ; break;
  case 1: m = TimeFormatter::JD  ; break;
  case 2: m = TimeFormatter::MJD ; break;
  case 3: m = TimeFormatter::CAL ; break;
  case 4: m = TimeFormatter::FITS; break;
  }
  _timeEdit->setMode(m);
  emit modeChanged(m);
}
