/*****************************************************************************
 *
 *  StringListEdit.cc                           XMM Science Analysis Subsystem
 *
 *  Qt widget for editing lists
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: StringListEdit.cc,v 1.2 1999/08/10 14:21:38 jbrumfit Exp $
 *
 *****************************************************************************/

#include <values.h>              // C headers

#include <iostream.h>            // C++ headers
#include <strstream.h>
#include <vector>

#include <qwidget.h>             // Qt headers
#include <qregexp.h>

#include "StringListEdit.h"      // Application headers
#include "StringFns.h"


//================================================================
//  Class StringListEdit
//================================================================

/*** Constructor ***/

StringListEdit::StringListEdit(QWidget *parent, const char *name)
  : ValidatedEdit(parent, name)
{
//    setRange(-MAXString, MAXString);
    setTextToValue();              // Update widget
}


/***  Return the latest valid value ***/

vector<string> StringListEdit::value() const
{
    return _value;
}


/*** Set the value and update display. ***/

void StringListEdit::setValue(vector<string> value)
{
    if(value != _value)
    {
        _value = value;
	setTextToValue();          // Update widget
    }
}


/*** Set widget text to current value ***/

void StringListEdit::setTextToValue()
{
    strstream ostr;
    vector<string>::const_iterator it = _value.begin();
    if(it != _value.end())
        ostr << '"' << *it++ << '"';
    while(it != _value.end())
        ostr << " \"" << *it++ << '"';
    ostr << ends;

    setText(ostr.str());
    delete ostr.str();
}


/*** Parse string and set value ***/

void StringListEdit::setValueToText()
{
    list<string> tokens = StringFns::splitStringList(string(text()));

    // Convert the list into a vector
    vector<string> values;
    list<string>::const_iterator it = tokens.begin();
    while(it != tokens.end())
	values.push_back(*it++);

    if(values != _value)
    {
        _value = values;
	emit valueChanged();
    }
}


/*** Test the hard constraint - valid syntax ***/

bool StringListEdit::isValid()
{
    return true;
}


/*** Test the soft constraint - value in range ***/

bool StringListEdit::isInRange()
{
    bool ok = true;

    list<string> tokens = StringFns::splitStringList(string(text()));
    list<string>::const_iterator it = tokens.begin();
    while(it != tokens.end())
	ok &= isValidValue(*it++);

    return ok;
}
