// -*-C++-*-
//
// File:      SasTaskWindow.h
// Author:    jbakker
// Generated: Fri Apr  7 21:03:27 MET DST 2000

#ifndef SasTaskWindow_h
#define SasTaskWindow_h

/*
  Description:
  ============

    Base class of all Qt-Tasks

    It provides a meachanism to run a Qt related task without interfering
    with the main-stream Event handler (i.e. modal window).
    The Window contains some SAS-defaults.

    Note that all task activity which is Qt based, should go into derived
    class of SasTaskWindow.


  Example usage:
  ==============

    class MyTask : public SasTaskWindow
    {
      // whatever exitement you want to implement here
      :
    };

    void mytask()
    {
       MyTask t;
       t->exec();
    }
 */



#include <qmainwindow.h>
class SasStyleMenu;
class SasHelpMenu;
class QPopupMenu;
namespace Info {class Task;}

class SasTaskWindow : public QMainWindow
{
  Q_OBJECT
public:
  SasTaskWindow(const char* name);
  virtual ~SasTaskWindow();

  // local execution of task. blocks all other Qt activities
  void exec();


  QPopupMenu* styleMenu() const;
  QPopupMenu* helpMenu() const;

public slots:
  void quit();
  void exit(int); 

protected:
  // only derived classes can use these

private:
  // member functions
  SasTaskWindow(const SasTaskWindow&);            // copy constructor (disabled)
  SasTaskWindow& operator=(const SasTaskWindow&); // assignment (disabled)

  /*
    re-implemented to for internal reasons
   */
  void closeEvent(QCloseEvent*);

  void returning();

  // member data
  SasStyleMenu* _style;
  SasHelpMenu*  _help;
};



#endif
