/*****************************************************************
 *
 *  System.cc                       XMM Science Analysis Subsystem
 *
 *  System utilities
 *
 *  (c) 1998 ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: System.cc,v 1.4 2000/06/29 08:38:33 jbakker Exp $
 *
 *****************************************************************/

#include "System.h"


#include <map>
#include <stdlib.h>
#include <time.h>
#include <strings.h>
#include <string.h>


/*
  Helper class: stores environment variables, such that we don't leak memory
 */
class SystemSetEnv_Imp : public map<string, char*, less< string > >
{
public:
  static SystemSetEnv_Imp* instance();
private:
  SystemSetEnv_Imp(){}
  static SystemSetEnv_Imp* _instance;
};

SystemSetEnv_Imp* SystemSetEnv_Imp::_instance=0;
SystemSetEnv_Imp* SystemSetEnv_Imp::instance()
{
  if (!_instance) _instance=new SystemSetEnv_Imp;
  return _instance;
}



/*****************************************************************
 *  Class System
 *****************************************************************/

/*** Get current date and time as a string ***/

string System::getDateTimeString()
{
    time_t tim = time(NULL);
    return string(asctime(localtime(&tim)));
}

bool System::getEnv(const string& name,string& val)
{
  char* v=::getenv(name.c_str());
  if (v) {
    val=v;
    return true;
  } else return false;
}

bool System::setEnv(const string& name,const string& val)
{
  SystemSetEnv_Imp* m=SystemSetEnv_Imp::instance();
  
  char* oldEnv=(*m)[name];
  char* newEnv=0;
  {
    string s(name + "=" + val);
    newEnv=new char[s.length()+1];
    strcpy(newEnv,s.c_str());
  }

  bool ok = ::putenv(newEnv) == 0;

  if (ok) {
    (*m)[name]=newEnv;
    delete oldEnv;
  }
  else 
    delete newEnv;
  return ok;
}

