/*****************************************************************************
 *
 *  SasMainWindow.h                             XMM Science Analysis Subsystem
 *
 *  Main window for the SAS GUI
 *
 *  (c) 1998 ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: SasMainWindow.h,v 1.27 2000/10/05 15:22:17 jbakker Exp $
 *
 *****************************************************************************/

#ifndef SASMAINWINDOW_H
#define SASMAINWINDOW_H

#include "SasTaskWindow.h"

#include <string>             // C++ headers

#include <qwidget.h>          // Qt headers
#include <qmenubar.h>
#include <qpopupmenu.h>
#include <qframe.h>
#include <qpushbutton.h>
#include <qsplitter.h>
#include <qtoolbar.h>
#include <qmainwindow.h>
#include <qprinter.h>

#include "GuiConst.h"         // Application headers
#include "ErrorHandler.h"
#include "TaskManager.h"
#include "LogPane.h"


//================================================================
//  Class SasMainWindow
//
//  Responsibilities:
//    - main application window
//    - browsing tasks
//    - invoking data-browser, help-viever, etc
//    - program exit
//
//================================================================

class SasMainWindow : public SasTaskWindow, private GuiConst
{
    Q_OBJECT

public:

    // Constructors and destructors
    SasMainWindow(const char *name="SAS" );
    ~SasMainWindow();

    // Initialisation
    void init();

private slots:
    
    // Application
    void    exit();
    void    notImplemented();
    void    transientMessage(const char* text);

    // Preferences
    void    editPreferences();

    // Task control
    void    editParam(const char* text);
    void    killTask();
    void    enableKill(bool enable);
    void    resetParamInfo();

    // Miscellaneous
    void    saveAsScript();
    void    print();
    void    browseDataset();
    void    writeCommandLog(const string&);

    // Testing (TEMPORARY)
    void    testWarning();
    void    testError();
    void    testFatal();
    void    testMessage1();
    void    testMessage2();
    void    test1();

    void    helpTasks();
private:

    // Initialisation
    void initPreferences();

    // Testing (TEMPORARY)
    QPopupMenu* setupTestMenu();

    // Disable copy constructor and operator=
    SasMainWindow(const SasMainWindow&);
    SasMainWindow& operator=(const SasMainWindow&);

    // Member data
    int             _exitID;
    string          _name;
    int             _killItem;
    TaskManager*    _taskManager;

    // Qt widgets
    QPopupMenu*     _fileMenu;
    QPopupMenu*     _taskMenu;
    LogPane*        _logPane;
    QSplitter *     _splitter;
    QFrame*         _frame;
    QToolBar*       _toolBar;
    QPrinter*       _printer;

    ErrorHandler*   _oldHandler;
};

#endif
