/*****************************************************************************
 *
 *  TaskBrowser.h                               XMM Science Analysis Subsystem
 *
 *  Browser for selecting tasks
 *
 *  (c) 1999  ESA  -  Written by Jon Brumfitt, Aurora
 *
 *  $Id: TaskBrowser.h,v 1.2 2000/05/11 12:48:46 jbakker Exp $
 *
 *****************************************************************************/

#ifndef TASKBROWSER_H
#define TASKBROWSER_H

#include <qlistview.h>

#include <map>

class QWidget;
class QMultiLineEdit;
class QListViewItem;


//================================================================
//  Class TaskInfo
//
//  Contains information on a single task
//================================================================

class TaskInfo
{
public:
  TaskInfo(const QString& description="<no info file present>",
	   const QString& groups="<unknown>",
	   bool visible=true)
    : _description(description),_groups(groups),_visible(visible) {}

  bool           visible()     const {return _visible;}
  const QString& description() const {return _description;}
  const QString& groups()      const {return _groups;}

  // returns the main group.
  QString        group();

  
  void read(const QString& file);

private:
  QString _description;
  QString _groups;
  bool    _visible;
};


//================================================================
//  Class TaskBrowser
//
//  Browser for selecting tasks from a list
//================================================================

class TaskBrowser : public QListView
{
    Q_OBJECT

public:
    TaskBrowser(QWidget *parent=0, const char *name=0);

signals:
    void run(const char* taskName);

private slots:
    void itemDoubleClicked(QListViewItem*);

private:
    void readTaskPar();
    void readTaskInfo();
    void readOldTaskInfo();
    void setup();

    // Member data
    map< QString, TaskInfo* > _info;
    int                      _history;
};


#endif
